@@ -107,7 +107,7 @@ class Install(InstallPlugin):
         if 'Slave' in self.type or self.type == 'Frontend':
             packages.add('ntp')              #causes mythtv-backend-master to go
             packages.add('mythtv-database')
-            packages.add('mysql-server-core-5.5')
+            packages.add('mysql-server-core-5.6')
         if 'Frontend' not in self.type:
             packages.add('mythtv-frontend')
         ## services that are installed by default
@@ -148,11 +148,11 @@ class Install(InstallPlugin):
                 shutil.copytree('/var/lib/mysql','/target/var/lib')
 
             #Setup sql server
-            install_misc.reconfigure(self.target, 'mysql-server-5.5')
+            install_misc.reconfigure(self.target, 'mysql-server-5.6')
 
             #upstart managed chroot job, 
             #we need stuff working INSIDE the chroot.
-            subprocess.call(['chroot', self.target, 'stop', 'mysql'])
+            subprocess.call(['chroot', self.target, 'systemctl', 'stop', 'mysql'])
             proc=subprocess.Popen(['chroot',self.target,'mysqld'])
             while not os.path.exists(os.path.join(self.target, 'run', 'mysqld', 'mysqld.sock')):
                 time.sleep(1)
@@ -161,8 +161,7 @@ class Install(InstallPlugin):
             install_misc.reconfigure(self.target, 'mythtv-database')
 
             #Cleanup
-            install_misc.chrex(self.target,'mysqladmin','--defaults-file=/etc/mysql/debian.cnf','shutdown')
-            proc.communicate()
+            proc.terminate()
 
             #Mythweb
             install_misc.set_debconf(self.target, 'mythweb/enable', 'true')
